@@ -11,7 +11,8 @@
 #  include <memory>
 #endif
 
-THRUST_BEGIN_NS
+namespace thrust
+{
 
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -28,5 +29,5 @@ T* addressof(T& arg)
 
 ///////////////////////////////////////////////////////////////////////////////
 
-THRUST_END_NS
+} // end namespace thrust
 
